==> haskell-authenticate-oauth-1.6-99-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-DUdIasxBZGs90HoAEtaXOO
key: authenticate-oauth-1.6-DUdIasxBZGs90HoAEtaXOO
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: 3af2d5a2606464d0bb606f684b3008fd
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-DUdIasxBZGs90HoAEtaXOO
depends:
    RSA-2.3.1-C31c3rMsZA2Cm3rRRxd0H SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    base-4.12.0.0 base64-bytestring-1.0.0.2-Isuu0DM5i6LOS2qIIf24
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-9aRaaM1sL6SBo9aXFfpDaA
    data-default-0.7.1.1-5ccnbkthejE9lCjbHMgc6
    http-client-0.6.4-FQWwfMstAnM2wFN0ZTXGGv
    http-types-0.12.3-3Nd2h8pfDaM3STPvc3OlR8
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.6-100-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-Df10Ps2kui1C0V38pYQpj3
key: authenticate-oauth-1.6-Df10Ps2kui1C0V38pYQpj3
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: ef3b7946cabae642f2136b27ee34e703
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-Df10Ps2kui1C0V38pYQpj3
depends:
    RSA-2.3.1-6yqOStudE18CKTblHlqNP7 SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    base-4.12.0.0 base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-BSiBW24og914FeEUxLBpGZ
    data-default-0.7.1.1-1LPfbbioWzl7RPD13iVYcW
    http-client-0.6.4-1ZFfhHOFZM7LvAxodh0J00
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
